==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/hr/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ovaj kv.",
	"field-quarter-short-relative+1": "sljedeći kv.",
	"field-tue-relative+-1": "prošli utorak",
	"field-year": "godina",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minuta",
	"field-month-narrow-relative+-1": "prošli mj.",
	"field-tue-narrow-relative+0": "ovaj uto.",
	"field-tue-narrow-relative+1": "sljedeći uto.",
	"field-day-short-relative+-1": "jučer",
	"field-thu-short-relative+0": "ovaj čet.",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "danas",
	"field-day-short-relative+-2": "prekjučer",
	"field-thu-short-relative+1": "sljedeći čet.",
	"field-day-relative+1": "sutra",
	"field-week-narrow-relative+0": "ovaj tj.",
	"field-day-relative+2": "prekosutra",
	"field-week-narrow-relative+1": "sljedeći tj.",
	"field-wed-narrow-relative+-1": "prošla sri.",
	"field-year-narrow": "g.",
	"field-year-narrow-relative+0": "ove g.",
	"field-tue-relative+0": "ovaj utorak",
	"field-year-narrow-relative+1": "sljedeće g.",
	"field-tue-relative+1": "sljedeći utorak",
	"field-second-short": "s",
	"dateFormatItem-MMMd": "d. MMM",
	"field-week-relative+0": "ovaj tjedan",
	"field-month-relative+0": "ovaj mjesec",
	"field-week-relative+1": "sljedeći tjedan",
	"field-month-relative+1": "sljedeći mjesec",
	"field-sun-narrow-relative+0": "ova ned.",
	"field-mon-short-relative+0": "ovaj pon.",
	"field-sun-narrow-relative+1": "sljedeća ned.",
	"field-mon-short-relative+1": "sljedeći pon.",
	"field-second-relative+0": "sad",
	"dateFormatItem-yyyyQQQ": "QQQ y. G",
	"field-month-short": "mj.",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-yyyyMd": "dd. MM. y. GGGGG",
	"field-day": "dan",
	"field-year-relative+-1": "prošle godine",
	"field-sat-short-relative+-1": "prošla sub.",
	"field-hour-relative+0": "ovaj sat",
	"dateFormatItem-yyyyMEd": "E, dd. MM. y. GGGGG",
	"field-wed-relative+-1": "prošla srijeda",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "prošla sub.",
	"field-second": "sekunda",
	"dateFormat-long": "d. MMMM y. G",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-quarter": "kvartal",
	"field-week-short": "tj.",
	"field-day-narrow-relative+0": "danas",
	"field-day-narrow-relative+1": "sutra",
	"field-day-narrow-relative+2": "prekosutra",
	"field-tue-short-relative+0": "ovaj uto.",
	"field-tue-short-relative+1": "sljedeći uto.",
	"field-month-short-relative+-1": "prošli mj.",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"dateFormatItem-GyMMM": "LLL y. G",
	"field-month": "mjesec",
	"field-day-narrow": "d.",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "ova sub.",
	"field-sat-short-relative+1": "sljedeća sub.",
	"dateFormat-medium": "d. MMM y. G",
	"dateFormatItem-yyyyMMMM": "LLLL y. G",
	"dateFormatItem-yyyyM": "MM. y. GGGGG",
	"field-second-narrow": "s",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"field-day-narrow-relative+-1": "jučer",
	"field-year-short": "g.",
	"field-day-narrow-relative+-2": "prekjučer",
	"field-quarter-relative+-1": "prošli kvartal",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"field-week-narrow-relative+-1": "prošli tj.",
	"field-sat-relative+-1": "prošla subota",
	"dateTimeFormat-long": "{1} 'u' {0}",
	"dateFormatItem-Md": "dd. MM.",
	"field-hour": "sat",
	"dateFormat-full": "EEEE, d. MMMM y. G",
	"field-month-relative+-1": "prošli mjesec",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "ova sub.",
	"field-fri-relative+0": "ovaj petak",
	"field-sat-narrow-relative+1": "sljedeća sub.",
	"field-fri-relative+1": "sljedeći petak",
	"field-month-narrow-relative+0": "ovaj mj.",
	"field-month-narrow-relative+1": "sljedeći mj.",
	"field-sun-short-relative+0": "ova ned.",
	"field-sun-short-relative+1": "sljedeća ned.",
	"field-week-relative+-1": "prošli tjedan",
	"field-quarter-short-relative+-1": "prošli kv.",
	"field-quarter-relative+0": "ovaj kvartal",
	"field-minute-relative+0": "ova minuta",
	"field-quarter-relative+1": "sljedeći kvartal",
	"field-wed-short-relative+-1": "prošla sri.",
	"dateFormat-short": "dd. MM. y. GGGGG",
	"field-year-narrow-relative+-1": "prošle g.",
	"field-thu-short-relative+-1": "prošli čet.",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"field-mon-narrow-relative+-1": "prošli pon.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "prošli čet.",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "prošli uto.",
	"dateFormatItem-H": "HH",
	"dateFormatItem-yyyy": "y. G",
	"field-wed-short-relative+0": "ova sri.",
	"dateFormatItem-M": "L.",
	"field-wed-short-relative+1": "sljedeća sri.",
	"field-sun-relative+-1": "prošla nedjelja",
	"dateFormatItem-MMMMEd": "E, d. MMMM",
	"dateTimeFormat-full": "{1} 'u' {0}",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormatItem-d": "d.",
	"field-weekday": "dan u tjednu",
	"field-day-short-relative+0": "danas",
	"field-quarter-narrow-relative+0": "ovaj kv.",
	"field-day-short-relative+1": "sutra",
	"field-sat-relative+0": "ova subota",
	"field-quarter-narrow-relative+1": "sljedeći kv.",
	"dateFormatItem-h": "hh a",
	"field-day-short-relative+2": "prekosutra",
	"field-sat-relative+1": "sljedeća subota",
	"field-week-short-relative+0": "ovaj tj.",
	"field-week-short-relative+1": "sljedeći tj.",
	"field-month-short-relative+0": "ovaj mj.",
	"field-month-short-relative+1": "sljedeći mj.",
	"dateFormatItem-MEd": "E, dd. MM.",
	"dateFormatItem-y": "y. G",
	"field-thu-narrow-relative+0": "ovaj čet.",
	"field-sun-narrow-relative+-1": "prošla ned.",
	"field-mon-short-relative+-1": "prošli pon.",
	"field-thu-narrow-relative+1": "sljedeći čet.",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-fri-short-relative+-1": "prošli pet.",
	"field-thu-relative+-1": "prošli četvrtak",
	"field-week": "tjedan",
	"dateFormatItem-Ed": "E, d.",
	"field-wed-narrow-relative+0": "ova sri.",
	"field-wed-narrow-relative+1": "sljedeća sri.",
	"field-quarter-narrow-relative+-1": "prošli kv.",
	"field-year-short-relative+0": "ove god.",
	"dateFormatItem-yyyyMMM": "LLL y. G",
	"field-year-short-relative+1": "sljedeće god.",
	"field-fri-short-relative+0": "ovaj pet.",
	"field-fri-short-relative+1": "sljedeći pet.",
	"field-week-short-relative+-1": "prošli tj.",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"field-hour-short": "h",
	"field-month-narrow": "m.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "prošli pet.",
	"field-year-relative+0": "ove godine",
	"field-year-relative+1": "sljedeće godine",
	"field-fri-relative+-1": "prošli petak",
	"field-tue-short-relative+-1": "prošli uto.",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "ovaj pon.",
	"field-mon-narrow-relative+1": "sljedeći pon.",
	"field-year-short-relative+-1": "prošle god.",
	"field-zone": "vremenska zona",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "prošla ned.",
	"field-day-relative+-1": "jučer",
	"field-day-relative+-2": "prekjučer",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"dateFormatItem-Gy": "y. G",
	"field-day-short": "d.",
	"field-week-narrow": "tj.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "ovaj pet.",
	"field-fri-narrow-relative+1": "sljedeći pet."
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/hr/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ovaj kv.",
	"field-quarter-short-relative+1": "sljedeći kv.",
	"field-tue-relative+-1": "prošli utorak",
	"field-year": "godina",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minuta",
	"field-month-narrow-relative+-1": "prošli mj.",
	"field-tue-narrow-relative+0": "ovaj uto.",
	"field-tue-narrow-relative+1": "sljedeći uto.",
	"field-day-short-relative+-1": "jučer",
	"field-thu-short-relative+0": "ovaj čet.",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "danas",
	"field-day-short-relative+-2": "prekjučer",
	"field-thu-short-relative+1": "sljedeći čet.",
	"field-day-relative+1": "sutra",
	"field-week-narrow-relative+0": "ovaj tj.",
	"field-day-relative+2": "prekosutra",
	"field-week-narrow-relative+1": "sljedeći tj.",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-wed-narrow-relative+-1": "prošla sri.",
	"field-year-narrow": "g.",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "ove g.",
	"field-tue-relative+0": "ovaj utorak",
	"field-year-narrow-relative+1": "sljedeće g.",
	"field-tue-relative+1": "sljedeći utorak",
	"field-weekdayOfMonth": "radni dan u mjesecu",
	"field-second-short": "s",
	"dateFormatItem-MMMd": "d. MMM",
	"field-weekdayOfMonth-narrow": "r. dan u mj.",
	"field-week-relative+0": "ovaj tjedan",
	"field-month-relative+0": "ovaj mjesec",
	"field-week-relative+1": "sljedeći tjedan",
	"field-month-relative+1": "sljedeći mjesec",
	"field-sun-narrow-relative+0": "ova ned.",
	"field-mon-short-relative+0": "ovaj pon.",
	"field-sun-narrow-relative+1": "sljedeća ned.",
	"field-mon-short-relative+1": "sljedeći pon.",
	"field-second-relative+0": "sad",
	"dateFormatItem-yyyyQQQ": "QQQ y. G",
	"field-weekOfMonth": "tjedan u mjesecu",
	"field-month-short": "mj.",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-yyyyMd": "dd. MM. y. GGGGG",
	"field-day": "dan",
	"field-dayOfYear-short": "dan u god.",
	"field-year-relative+-1": "prošle godine",
	"field-sat-short-relative+-1": "prošla sub.",
	"field-hour-relative+0": "ovaj sat",
	"dateFormatItem-yyyyMEd": "E, dd. MM. y. GGGGG",
	"field-wed-relative+-1": "prošla srijeda",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "prošla sub.",
	"field-second": "sekunda",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "d. MMMM y. G",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-quarter": "kvartal",
	"field-week-short": "tj.",
	"field-day-narrow-relative+0": "danas",
	"field-day-narrow-relative+1": "sutra",
	"field-day-narrow-relative+2": "prekosutra",
	"field-tue-short-relative+0": "ovaj uto.",
	"field-tue-short-relative+1": "sljedeći uto.",
	"field-month-short-relative+-1": "prošli mj.",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"dateFormatItem-GyMMM": "LLL y. G",
	"field-month": "mjesec",
	"field-day-narrow": "d.",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "ova sub.",
	"field-sat-short-relative+1": "sljedeća sub.",
	"dateFormat-medium": "d. MMM y. G",
	"dateFormatItem-yyyyMMMM": "LLLL y. G",
	"dateFormatItem-yyyyM": "MM. y. GGGGG",
	"field-second-narrow": "s",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"field-day-narrow-relative+-1": "jučer",
	"field-year-short": "g.",
	"field-day-narrow-relative+-2": "prekjučer",
	"field-quarter-relative+-1": "prošli kvartal",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"field-dayperiod-narrow": "AM/PM",
	"field-week-narrow-relative+-1": "prošli tj.",
	"field-dayOfYear": "dan u godini",
	"field-sat-relative+-1": "prošla subota",
	"dateTimeFormat-long": "{1} 'u' {0}",
	"dateFormatItem-Md": "dd. MM.",
	"field-hour": "sat",
	"dateFormat-full": "EEEE, d. MMMM y. G",
	"field-month-relative+-1": "prošli mjesec",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "ova sub.",
	"field-fri-relative+0": "ovaj petak",
	"field-sat-narrow-relative+1": "sljedeća sub.",
	"field-fri-relative+1": "sljedeći petak",
	"dateFormatItem-EBhm": "E h:mm B",
	"field-month-narrow-relative+0": "ovaj mj.",
	"field-month-narrow-relative+1": "sljedeći mj.",
	"field-sun-short-relative+0": "ova ned.",
	"field-sun-short-relative+1": "sljedeća ned.",
	"field-week-relative+-1": "prošli tjedan",
	"field-quarter-short-relative+-1": "prošli kv.",
	"dateFormatItem-Ehm": "E h:mm a",
	"field-quarter-relative+0": "ovaj kvartal",
	"field-minute-relative+0": "ova minuta",
	"field-quarter-relative+1": "sljedeći kvartal",
	"field-wed-short-relative+-1": "prošla sri.",
	"dateFormat-short": "dd. MM. y. GGGGG",
	"dateFormatItem-Bh": "h B",
	"field-year-narrow-relative+-1": "prošle g.",
	"field-thu-short-relative+-1": "prošli čet.",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"field-mon-narrow-relative+-1": "prošli pon.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "prošli čet.",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "tj. u mj.",
	"field-tue-narrow-relative+-1": "prošli uto.",
	"dateFormatItem-yyyy": "y. G",
	"dateFormatItem-M": "L.",
	"field-wed-short-relative+0": "ova sri.",
	"field-wed-short-relative+1": "sljedeća sri.",
	"field-sun-relative+-1": "prošla nedjelja",
	"dateFormatItem-MMMMEd": "E, d. MMMM",
	"dateTimeFormat-full": "{1} 'u' {0}",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormatItem-d": "d.",
	"field-weekday": "dan u tjednu",
	"field-day-short-relative+0": "danas",
	"field-quarter-narrow-relative+0": "ovaj kv.",
	"field-day-short-relative+1": "sutra",
	"field-sat-relative+0": "ova subota",
	"field-quarter-narrow-relative+1": "sljedeći kv.",
	"dateFormatItem-h": "hh a",
	"field-day-short-relative+2": "prekosutra",
	"field-sat-relative+1": "sljedeća subota",
	"field-week-short-relative+0": "ovaj tj.",
	"field-week-short-relative+1": "sljedeći tj.",
	"field-dayOfYear-narrow": "dan u g.",
	"field-month-short-relative+0": "ovaj mj.",
	"field-month-short-relative+1": "sljedeći mj.",
	"field-weekdayOfMonth-short": "radni dan u mj.",
	"dateFormatItem-MEd": "E, dd. MM.",
	"field-zone-narrow": "zona",
	"dateFormatItem-y": "y. G",
	"field-thu-narrow-relative+0": "ovaj čet.",
	"field-sun-narrow-relative+-1": "prošla ned.",
	"field-mon-short-relative+-1": "prošli pon.",
	"field-thu-narrow-relative+1": "sljedeći čet.",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-fri-short-relative+-1": "prošli pet.",
	"field-thu-relative+-1": "prošli četvrtak",
	"field-week": "tjedan",
	"dateFormatItem-Ed": "E, d.",
	"field-wed-narrow-relative+0": "ova sri.",
	"field-wed-narrow-relative+1": "sljedeća sri.",
	"field-quarter-narrow-relative+-1": "prošli kv.",
	"field-year-short-relative+0": "ove god.",
	"dateFormatItem-yyyyMMM": "LLL y. G",
	"field-dayperiod-short": "AM/PM",
	"field-year-short-relative+1": "sljedeće god.",
	"field-fri-short-relative+0": "ovaj pet.",
	"field-fri-short-relative+1": "sljedeći pet.",
	"field-week-short-relative+-1": "prošli tj.",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"field-hour-short": "h",
	"field-zone-short": "zona",
	"field-month-narrow": "m.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "prošli pet.",
	"field-year-relative+0": "ove godine",
	"field-year-relative+1": "sljedeće godine",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "prošli petak",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-tue-short-relative+-1": "prošli uto.",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "ovaj pon.",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "sljedeći pon.",
	"field-year-short-relative+-1": "prošle god.",
	"field-zone": "vremenska zona",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-weekOfMonth-narrow": "tj. u mjesecu",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-weekday-narrow": "dan u tj.",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "prošla ned.",
	"field-day-relative+-1": "jučer",
	"field-day-relative+-2": "prekjučer",
	"field-weekday-short": "dan u tjed.",
	"dateFormatItem-Bhm": "h:mm B",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"dateFormatItem-Gy": "y. G",
	"field-day-short": "d.",
	"field-week-narrow": "tj.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "ovaj pet.",
	"field-fri-narrow-relative+1": "sljedeći pet."
}
//end v1.x content
);
